Documentation
¶
Index ¶
- Variables
- func RegisterKeyAgentServer(s grpc.ServiceRegistrar, srv KeyAgentServer)
- type KeyAgentClient
- type KeyAgentServer
- type ListKeysRequest
- type ListKeysResponse
- type PingRequest
- type PingResponse
- func (*PingResponse) Descriptor() ([]byte, []int)deprecated
- func (x *PingResponse) GetRunning() bool
- func (x *PingResponse) GetVersion() string
- func (*PingResponse) ProtoMessage()
- func (x *PingResponse) ProtoReflect() protoreflect.Message
- func (x *PingResponse) Reset()
- func (x *PingResponse) String() string
- type RetrieveKeyRequest
- func (*RetrieveKeyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RetrieveKeyRequest) GetKeyName() string
- func (x *RetrieveKeyRequest) GetPassphrase() string
- func (*RetrieveKeyRequest) ProtoMessage()
- func (x *RetrieveKeyRequest) ProtoReflect() protoreflect.Message
- func (x *RetrieveKeyRequest) Reset()
- func (x *RetrieveKeyRequest) String() string
- type RetrieveKeyResponse
- func (*RetrieveKeyResponse) Descriptor() ([]byte, []int)deprecated
- func (x *RetrieveKeyResponse) GetPrivateKey() string
- func (*RetrieveKeyResponse) ProtoMessage()
- func (x *RetrieveKeyResponse) ProtoReflect() protoreflect.Message
- func (x *RetrieveKeyResponse) Reset()
- func (x *RetrieveKeyResponse) String() string
- type StoreKeyRequest
- func (*StoreKeyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *StoreKeyRequest) GetKeyName() string
- func (x *StoreKeyRequest) GetPassphrase() string
- func (x *StoreKeyRequest) GetPrivateKey() string
- func (*StoreKeyRequest) ProtoMessage()
- func (x *StoreKeyRequest) ProtoReflect() protoreflect.Message
- func (x *StoreKeyRequest) Reset()
- func (x *StoreKeyRequest) String() string
- type StoreKeyResponse
- type UnimplementedKeyAgentServer
- func (UnimplementedKeyAgentServer) ListKeys(context.Context, *ListKeysRequest) (*ListKeysResponse, error)
- func (UnimplementedKeyAgentServer) Ping(context.Context, *PingRequest) (*PingResponse, error)
- func (UnimplementedKeyAgentServer) RetrieveKey(context.Context, *RetrieveKeyRequest) (*RetrieveKeyResponse, error)
- func (UnimplementedKeyAgentServer) StoreKey(context.Context, *StoreKeyRequest) (*StoreKeyResponse, error)
- type UnsafeKeyAgentServer
Constants ¶
This section is empty.
Variables ¶
var File_agent_protobuf protoreflect.FileDescriptor
var KeyAgent_ServiceDesc = grpc.ServiceDesc{ ServiceName: "nestrkeyagent.KeyAgent", HandlerType: (*KeyAgentServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "StoreKey", Handler: _KeyAgent_StoreKey_Handler, }, { MethodName: "RetrieveKey", Handler: _KeyAgent_RetrieveKey_Handler, }, { MethodName: "ListKeys", Handler: _KeyAgent_ListKeys_Handler, }, { MethodName: "Ping", Handler: _KeyAgent_Ping_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "agent.protobuf", }
KeyAgent_ServiceDesc is the grpc.ServiceDesc for KeyAgent service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterKeyAgentServer ¶
func RegisterKeyAgentServer(s grpc.ServiceRegistrar, srv KeyAgentServer)
Types ¶
type KeyAgentClient ¶
type KeyAgentClient interface {
StoreKey(ctx context.Context, in *StoreKeyRequest, opts ...grpc.CallOption) (*StoreKeyResponse, error)
RetrieveKey(ctx context.Context, in *RetrieveKeyRequest, opts ...grpc.CallOption) (*RetrieveKeyResponse, error)
ListKeys(ctx context.Context, in *ListKeysRequest, opts ...grpc.CallOption) (*ListKeysResponse, error)
Ping(ctx context.Context, in *PingRequest, opts ...grpc.CallOption) (*PingResponse, error)
}
KeyAgentClient is the client API for KeyAgent service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewKeyAgentClient ¶
func NewKeyAgentClient(cc grpc.ClientConnInterface) KeyAgentClient
type KeyAgentServer ¶
type KeyAgentServer interface {
StoreKey(context.Context, *StoreKeyRequest) (*StoreKeyResponse, error)
RetrieveKey(context.Context, *RetrieveKeyRequest) (*RetrieveKeyResponse, error)
ListKeys(context.Context, *ListKeysRequest) (*ListKeysResponse, error)
Ping(context.Context, *PingRequest) (*PingResponse, error)
}
KeyAgentServer is the server API for KeyAgent service. All implementations should embed UnimplementedKeyAgentServer for forward compatibility
type ListKeysRequest ¶ added in v1.1.7
type ListKeysRequest struct {
// contains filtered or unexported fields
}
func (*ListKeysRequest) Descriptor
deprecated
added in
v1.1.7
func (*ListKeysRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListKeysRequest.ProtoReflect.Descriptor instead.
func (*ListKeysRequest) ProtoMessage ¶ added in v1.1.7
func (*ListKeysRequest) ProtoMessage()
func (*ListKeysRequest) ProtoReflect ¶ added in v1.1.7
func (x *ListKeysRequest) ProtoReflect() protoreflect.Message
func (*ListKeysRequest) Reset ¶ added in v1.1.7
func (x *ListKeysRequest) Reset()
func (*ListKeysRequest) String ¶ added in v1.1.7
func (x *ListKeysRequest) String() string
type ListKeysResponse ¶ added in v1.1.7
type ListKeysResponse struct {
KeyNames []string `protobuf:"bytes,1,rep,name=keyNames,proto3" json:"keyNames,omitempty"`
// contains filtered or unexported fields
}
func (*ListKeysResponse) Descriptor
deprecated
added in
v1.1.7
func (*ListKeysResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListKeysResponse.ProtoReflect.Descriptor instead.
func (*ListKeysResponse) GetKeyNames ¶ added in v1.1.7
func (x *ListKeysResponse) GetKeyNames() []string
func (*ListKeysResponse) ProtoMessage ¶ added in v1.1.7
func (*ListKeysResponse) ProtoMessage()
func (*ListKeysResponse) ProtoReflect ¶ added in v1.1.7
func (x *ListKeysResponse) ProtoReflect() protoreflect.Message
func (*ListKeysResponse) Reset ¶ added in v1.1.7
func (x *ListKeysResponse) Reset()
func (*ListKeysResponse) String ¶ added in v1.1.7
func (x *ListKeysResponse) String() string
type PingRequest ¶ added in v1.1.7
type PingRequest struct {
// contains filtered or unexported fields
}
func (*PingRequest) Descriptor
deprecated
added in
v1.1.7
func (*PingRequest) Descriptor() ([]byte, []int)
Deprecated: Use PingRequest.ProtoReflect.Descriptor instead.
func (*PingRequest) ProtoMessage ¶ added in v1.1.7
func (*PingRequest) ProtoMessage()
func (*PingRequest) ProtoReflect ¶ added in v1.1.7
func (x *PingRequest) ProtoReflect() protoreflect.Message
func (*PingRequest) Reset ¶ added in v1.1.7
func (x *PingRequest) Reset()
func (*PingRequest) String ¶ added in v1.1.7
func (x *PingRequest) String() string
type PingResponse ¶ added in v1.1.7
type PingResponse struct {
Running bool `protobuf:"varint,1,opt,name=running,proto3" json:"running,omitempty"`
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
// contains filtered or unexported fields
}
func (*PingResponse) Descriptor
deprecated
added in
v1.1.7
func (*PingResponse) Descriptor() ([]byte, []int)
Deprecated: Use PingResponse.ProtoReflect.Descriptor instead.
func (*PingResponse) GetRunning ¶ added in v1.1.7
func (x *PingResponse) GetRunning() bool
func (*PingResponse) GetVersion ¶ added in v1.1.7
func (x *PingResponse) GetVersion() string
func (*PingResponse) ProtoMessage ¶ added in v1.1.7
func (*PingResponse) ProtoMessage()
func (*PingResponse) ProtoReflect ¶ added in v1.1.7
func (x *PingResponse) ProtoReflect() protoreflect.Message
func (*PingResponse) Reset ¶ added in v1.1.7
func (x *PingResponse) Reset()
func (*PingResponse) String ¶ added in v1.1.7
func (x *PingResponse) String() string
type RetrieveKeyRequest ¶
type RetrieveKeyRequest struct {
KeyName string `protobuf:"bytes,1,opt,name=keyName,proto3" json:"keyName,omitempty"`
Passphrase string `protobuf:"bytes,2,opt,name=passphrase,proto3" json:"passphrase,omitempty"`
// contains filtered or unexported fields
}
func (*RetrieveKeyRequest) Descriptor
deprecated
func (*RetrieveKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use RetrieveKeyRequest.ProtoReflect.Descriptor instead.
func (*RetrieveKeyRequest) GetKeyName ¶
func (x *RetrieveKeyRequest) GetKeyName() string
func (*RetrieveKeyRequest) GetPassphrase ¶
func (x *RetrieveKeyRequest) GetPassphrase() string
func (*RetrieveKeyRequest) ProtoMessage ¶
func (*RetrieveKeyRequest) ProtoMessage()
func (*RetrieveKeyRequest) ProtoReflect ¶
func (x *RetrieveKeyRequest) ProtoReflect() protoreflect.Message
func (*RetrieveKeyRequest) Reset ¶
func (x *RetrieveKeyRequest) Reset()
func (*RetrieveKeyRequest) String ¶
func (x *RetrieveKeyRequest) String() string
type RetrieveKeyResponse ¶
type RetrieveKeyResponse struct {
PrivateKey string `protobuf:"bytes,1,opt,name=privateKey,proto3" json:"privateKey,omitempty"`
// contains filtered or unexported fields
}
func (*RetrieveKeyResponse) Descriptor
deprecated
func (*RetrieveKeyResponse) Descriptor() ([]byte, []int)
Deprecated: Use RetrieveKeyResponse.ProtoReflect.Descriptor instead.
func (*RetrieveKeyResponse) GetPrivateKey ¶
func (x *RetrieveKeyResponse) GetPrivateKey() string
func (*RetrieveKeyResponse) ProtoMessage ¶
func (*RetrieveKeyResponse) ProtoMessage()
func (*RetrieveKeyResponse) ProtoReflect ¶
func (x *RetrieveKeyResponse) ProtoReflect() protoreflect.Message
func (*RetrieveKeyResponse) Reset ¶
func (x *RetrieveKeyResponse) Reset()
func (*RetrieveKeyResponse) String ¶
func (x *RetrieveKeyResponse) String() string
type StoreKeyRequest ¶
type StoreKeyRequest struct {
KeyName string `protobuf:"bytes,1,opt,name=keyName,proto3" json:"keyName,omitempty"`
PrivateKey string `protobuf:"bytes,2,opt,name=privateKey,proto3" json:"privateKey,omitempty"`
Passphrase string `protobuf:"bytes,3,opt,name=passphrase,proto3" json:"passphrase,omitempty"`
// contains filtered or unexported fields
}
func (*StoreKeyRequest) Descriptor
deprecated
func (*StoreKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use StoreKeyRequest.ProtoReflect.Descriptor instead.
func (*StoreKeyRequest) GetKeyName ¶
func (x *StoreKeyRequest) GetKeyName() string
func (*StoreKeyRequest) GetPassphrase ¶
func (x *StoreKeyRequest) GetPassphrase() string
func (*StoreKeyRequest) GetPrivateKey ¶
func (x *StoreKeyRequest) GetPrivateKey() string
func (*StoreKeyRequest) ProtoMessage ¶
func (*StoreKeyRequest) ProtoMessage()
func (*StoreKeyRequest) ProtoReflect ¶
func (x *StoreKeyRequest) ProtoReflect() protoreflect.Message
func (*StoreKeyRequest) Reset ¶
func (x *StoreKeyRequest) Reset()
func (*StoreKeyRequest) String ¶
func (x *StoreKeyRequest) String() string
type StoreKeyResponse ¶
type StoreKeyResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
// contains filtered or unexported fields
}
func (*StoreKeyResponse) Descriptor
deprecated
func (*StoreKeyResponse) Descriptor() ([]byte, []int)
Deprecated: Use StoreKeyResponse.ProtoReflect.Descriptor instead.
func (*StoreKeyResponse) GetSuccess ¶
func (x *StoreKeyResponse) GetSuccess() bool
func (*StoreKeyResponse) ProtoMessage ¶
func (*StoreKeyResponse) ProtoMessage()
func (*StoreKeyResponse) ProtoReflect ¶
func (x *StoreKeyResponse) ProtoReflect() protoreflect.Message
func (*StoreKeyResponse) Reset ¶
func (x *StoreKeyResponse) Reset()
func (*StoreKeyResponse) String ¶
func (x *StoreKeyResponse) String() string
type UnimplementedKeyAgentServer ¶
type UnimplementedKeyAgentServer struct {
}
UnimplementedKeyAgentServer should be embedded to have forward compatible implementations.
func (UnimplementedKeyAgentServer) ListKeys ¶ added in v1.1.7
func (UnimplementedKeyAgentServer) ListKeys(context.Context, *ListKeysRequest) (*ListKeysResponse, error)
func (UnimplementedKeyAgentServer) Ping ¶ added in v1.1.7
func (UnimplementedKeyAgentServer) Ping(context.Context, *PingRequest) (*PingResponse, error)
func (UnimplementedKeyAgentServer) RetrieveKey ¶
func (UnimplementedKeyAgentServer) RetrieveKey(context.Context, *RetrieveKeyRequest) (*RetrieveKeyResponse, error)
func (UnimplementedKeyAgentServer) StoreKey ¶
func (UnimplementedKeyAgentServer) StoreKey(context.Context, *StoreKeyRequest) (*StoreKeyResponse, error)
type UnsafeKeyAgentServer ¶
type UnsafeKeyAgentServer interface {
// contains filtered or unexported methods
}
UnsafeKeyAgentServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to KeyAgentServer will result in compilation errors.