Documentation
¶
Index ¶
- type KeyAgentClient
- func (c *KeyAgentClient) Close() error
- func (c *KeyAgentClient) ListKeys() ([]string, error)
- func (c *KeyAgentClient) Ping() (bool, string, error)
- func (c *KeyAgentClient) RetrieveKey(keyName, passphrase string) (string, error)
- func (c *KeyAgentClient) StoreKey(keyName, privateKey, passphrase string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KeyAgentClient ¶
type KeyAgentClient struct {
// contains filtered or unexported fields
}
func NewKeyAgentClient ¶
func NewKeyAgentClient() (*KeyAgentClient, error)
func (*KeyAgentClient) Close ¶
func (c *KeyAgentClient) Close() error
func (*KeyAgentClient) ListKeys ¶ added in v1.1.7
func (c *KeyAgentClient) ListKeys() ([]string, error)
ListKeys returns all key names stored in the key agent
func (*KeyAgentClient) Ping ¶ added in v1.1.7
func (c *KeyAgentClient) Ping() (bool, string, error)
Ping checks if the key agent is running and returns version info
func (*KeyAgentClient) RetrieveKey ¶
func (c *KeyAgentClient) RetrieveKey(keyName, passphrase string) (string, error)
func (*KeyAgentClient) StoreKey ¶
func (c *KeyAgentClient) StoreKey(keyName, privateKey, passphrase string) error
Click to show internal directories.
Click to hide internal directories.